"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandCategories = void 0;
var chalk_1 = __importDefault(require("chalk"));
var configstore_1 = __importDefault(require("./configstore"));
var getCurrentConfig_1 = __importDefault(require("./getCurrentConfig"));
var isCI_1 = __importDefault(require("./isCI"));
var logger_1 = require("./logger");
var loginFlow_1 = __importDefault(require("./loginFlow"));
var CommandCategories;
(function (CommandCategories) {
    CommandCategories["ADMIN"] = "admin";
    CommandCategories["APIS"] = "apis";
    CommandCategories["CATEGORIES"] = "categories";
    CommandCategories["CHANGELOGS"] = "changelogs";
    CommandCategories["CUSTOM_PAGES"] = "custompages";
    CommandCategories["DOCS"] = "docs";
    CommandCategories["UTILITIES"] = "utilities";
    CommandCategories["VERSIONS"] = "versions";
})(CommandCategories || (exports.CommandCategories = CommandCategories = {}));
var Command = /** @class */ (function () {
    function Command() {
        /**
         * Should the command be hidden from our `--help` screens?
         */
        this.hidden = false;
        /**
         * Does the command run the GitHub Actions onboarding called via
         * `src/index.ts`?
         */
        this.supportsGHA = false;
        /**
         * Arguments to hide from the individual command help screen
         * (typically used for hiding default arguments)
         *
         * @example ['spec']
         */
        this.hiddenArgs = [];
    }
    Command.prototype.run = function (opts) {
        return __awaiter(this, void 0, void 0, function () {
            var _a, email, project, result;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        Command.debug("command: ".concat(this.command));
                        Command.debug("opts: ".concat(JSON.stringify(opts)));
                        if (!this.args.some(function (arg) { return arg.name === 'key'; })) return [3 /*break*/, 2];
                        _a = (0, getCurrentConfig_1.default)(), email = _a.email, project = _a.project;
                        // We only want to log this if the API key is stored in the configstore, **not** in an env var.
                        if (opts.key && configstore_1.default.get('apiKey') === opts.key) {
                            (0, logger_1.info)("\uD83D\uDD11 ".concat(chalk_1.default.green(email), " is currently logged in, using the stored API key for this project: ").concat(chalk_1.default.blue(project)), { includeEmojiPrefix: false });
                        }
                        if (!!opts.key) return [3 /*break*/, 2];
                        if ((0, isCI_1.default)()) {
                            throw new Error('No project API key provided. Please use `--key`.');
                        }
                        (0, logger_1.info)("Looks like you're missing a ReadMe API key, let's fix that! 🦉", { includeEmojiPrefix: false });
                        return [4 /*yield*/, (0, loginFlow_1.default)()];
                    case 1:
                        result = _b.sent();
                        (0, logger_1.info)(result, { includeEmojiPrefix: false });
                        // eslint-disable-next-line no-param-reassign
                        opts.key = configstore_1.default.get('apiKey');
                        _b.label = 2;
                    case 2:
                        if (opts.github && (0, isCI_1.default)()) {
                            throw new Error('The `--github` flag is only for usage in non-CI environments.');
                        }
                        // This is a bit of a hack so we can keep our types consistent
                        // for this `run` function.
                        return [2 /*return*/, Promise.resolve('')];
                }
            });
        });
    };
    /**
     * Used in any command where `github` is an option.
     */
    Command.prototype.getGitHubArg = function () {
        return {
            name: 'github',
            type: Boolean,
            description: 'Create a new GitHub Actions workflow for this command.',
        };
    };
    /**
     * Used in any command where `key` is an option.
     */
    Command.prototype.getKeyArg = function () {
        return {
            name: 'key',
            type: String,
            description: 'Project API key',
        };
    };
    /**
     * Used in the `openapi` family of commands where `title` is an option.
     */
    Command.prototype.getTitleArg = function () {
        return {
            name: 'title',
            type: String,
            description: 'An override value for the `info.title` field in the API definition',
        };
    };
    /**
     * Used in any command where `version` is an option.
     */
    Command.prototype.getVersionArg = function () {
        return {
            name: 'version',
            type: String,
            description: 'Project version. If running command in a CI environment and this option is not passed, the main project version will be used.',
        };
    };
    /**
     * Used in the `versions:create` and `versions:update` commands.
     */
    Command.prototype.getVersionOpts = function () {
        return [
            {
                name: 'codename',
                type: String,
                description: 'The codename, or nickname, for a particular version.',
            },
            {
                name: 'main',
                type: String,
                description: "Should this version be the primary (default) version for your project? (Must be 'true' or 'false')",
            },
            {
                name: 'beta',
                type: String,
                description: "Is this version in beta? (Must be 'true' or 'false')",
            },
            {
                name: 'isPublic',
                type: String,
                description: "Would you like to make this version public? Any primary version must be public. (Must be 'true' or 'false')",
            },
        ];
    };
    /**
     * Used in the `openapi` family of commands where `workingDirectory` is an option.
     */
    Command.prototype.getWorkingDirArg = function () {
        return {
            name: 'workingDirectory',
            type: String,
            description: 'Working directory (for usage with relative external references)',
        };
    };
    Command.debug = function (msg) {
        (0, logger_1.debug)(msg);
    };
    Command.info = function (msg) {
        (0, logger_1.info)(msg);
    };
    Command.warn = function (msg) {
        (0, logger_1.warn)(msg);
    };
    return Command;
}());
exports.default = Command;
