"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var crypto_1 = __importDefault(require("crypto"));
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var gray_matter_1 = __importDefault(require("gray-matter"));
var logger_1 = require("./logger");
/**
 * Returns the content, matter and slug of the specified Markdown or HTML file
 *
 * @param {String} filepath path to the HTML/Markdown file
 *  (file extension must end in `.html`, `.md`., or `.markdown`)
 */
function readDoc(filepath) {
    (0, logger_1.debug)("reading file ".concat(filepath));
    var rawFileContents = fs_1.default.readFileSync(filepath, 'utf8');
    var matter = (0, gray_matter_1.default)(rawFileContents);
    var content = matter.content, data = matter.data;
    (0, logger_1.debug)("front matter for ".concat(filepath, ": ").concat(JSON.stringify(matter)));
    // Stripping the subdirectories and markdown extension from the filename and lowercasing to get the default slug.
    var slug = matter.data.slug || path_1.default.basename(filepath).replace(path_1.default.extname(filepath), '').toLowerCase();
    var hash = crypto_1.default.createHash('sha1').update(rawFileContents).digest('hex');
    return { content: content, data: data, hash: hash, slug: slug };
}
exports.default = readDoc;
