"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var ignore_1 = __importDefault(require("ignore"));
var logger_1 = require("./logger");
/**
 * Recursively grabs all files within a given directory
 * (including subdirectories)
 * @param folderToSearch path to directory
 * @param ignoreGit boolean to indicate whether or not to ignore
 * `.git` directory plus any files specified in `.gitignore`
 * @returns array of file names
 */
function readdirRecursive(folderToSearch, ignoreGit) {
    if (ignoreGit === void 0) { ignoreGit = false; }
    (0, logger_1.debug)("current readdirRecursive folder: ".concat(folderToSearch));
    var ignoreFilter;
    if (ignoreGit) {
        // Initialize ignore filter with `.git` directory
        ignoreFilter = (0, ignore_1.default)().add(path_1.default.join(folderToSearch, '.git/'));
        // If .gitignore file exists, load its contents into ignore filter
        if (fs_1.default.existsSync(path_1.default.join(folderToSearch, '.gitignore'))) {
            (0, logger_1.debug)('.gitignore file found, adding to ignore filter');
            ignoreFilter.add(fs_1.default.readFileSync(path_1.default.join(folderToSearch, '.gitignore')).toString());
        }
    }
    var filesInFolder = fs_1.default.readdirSync(folderToSearch, { withFileTypes: true }).filter(function (item) {
        if (!ignoreGit)
            return true;
        // Some logic to construct pathname the way that `ignore` package consumes it
        // https://github.com/kaelzhang/node-ignore#2-filenames-and-dirnames
        var fullPathName = path_1.default.join(folderToSearch, item.name);
        if (item.isDirectory())
            fullPathName = "".concat(fullPathName, "/");
        return !ignoreFilter.ignores(fullPathName);
    });
    var files = filesInFolder
        .filter(function (fileHandle) { return fileHandle.isFile(); })
        .map(function (fileHandle) { return path_1.default.join(folderToSearch, fileHandle.name); });
    var folders = filesInFolder.filter(function (fileHandle) { return fileHandle.isDirectory(); });
    var subFiles = [].concat.apply([], __spreadArray([], __read(folders.map(function (fileHandle) { return readdirRecursive(path_1.default.join(folderToSearch, fileHandle.name), ignoreGit); })), false));
    return __spreadArray(__spreadArray([], __read(files), false), __read(subFiles), false);
}
exports.default = readdirRecursive;
